<p align="center">
    <a href="github.address">
        <img src="https://upcdn.io/W142hJk/thumbnail/demo/4mrDXtYPJA.png.crop" alt="evatygram" width="128">
    </a>
    <br>
    <b>Rubika API Framework for Python</b>
    <br>
    <a href="home">
        Homepage
    </a>
    •
    <a href="https://t.me/evatygram_doc">
        Documentation
    </a>
    •
    <a href="https://pypi.org/project/evatygram/#history">
        Releases
    </a>
    •
    <a href="https://t.me/rubika_library">
        News
    </a>
</p>

## evatygram

> Elegant, modern and asynchronous Rubika API framework in Python for users and bots

``` python
from evatygram import Client

app = Client("my_account")

@app.Handler
async def hello(message):
    await app.sendMessage(message.get('object-guid'), 'Hello from **evatygram**!')


```

**evatygram** is a modern, elegant and asynchronous framework. It enables you to easily interact with the main Rubika API through a user account (custom client) or a bot
identity (bot API alternative) using Python.


### Key Features

- **Ready**: Install evatygram with pip and start building your applications right away.
- **Easy**: Makes the Rubika API simple and intuitive, while still allowing advanced usages.
- **Elegant**: Low-level details are abstracted and re-presented in a more convenient way.
- **Fast**: Boosted up by pycryptodome, ujson and urllib3, a high-performance cryptography library written in C.
- **Async**: Fully asynchronous (also usable synchronously if wanted, for convenience).
- **Powerful**: Full access to Rubika's API to execute any official client action and more.

### Installing

``` bash
pip3 install evatygram
```